<?php

namespace NF\Discord\Admin\Controller;

use XF\Admin\Controller\AbstractController;

use NF\Discord\Api;
use XF\Mvc\ParameterBag;

class Channel extends AbstractController
{
	public function actionIndex()
	{
		$api = Api::factory();

		$viewParams = [
			'channels' => $api->getChannels(Api::CHANNEL_TYPE_BOTH),
		];

		return $this->view(
			'NF\Discord:Channel\List',
			'nf_discord_channel_list',
			$viewParams
		);
	}

	public function actionEdit(ParameterBag $params)
	{
		$channel = $this->assertChannelExists($params['id']);

		$viewParams = [
			'channel' => $channel,
		];
		return $this->view('NF\Discord:Channel\Edit', 'nf_discord_channel_edit', $viewParams);
	}

	public function actionSave(ParameterBag $params)
	{
		$this->assertPostOnly();

		$channel = $this->assertChannelExists($params['id']);

		$data = $this->filter([
			'name' => 'str',
			'type' => 'str',
			'topic' => 'str',
			'position' => 'uint',
			'bitrate' => 'uint',
			'user_limit' => 'uint',
		]);

		$api = Api::factory();
		$api->patchChannel($channel['id'], $data);

		return $this->redirect($this->buildLink('discord/channels'));
	}

	public function actionDelete(ParameterBag $params)
	{
		$channel = $this->assertChannelExists($params['id']);
		$api = Api::factory();

		if ($this->isPost())
		{
			$api->deleteChannel($channel['id']);

			return $this->redirect($this->buildLink('discord/channels'));
		}
		else
		{
			$viewParams = [
				'channel' => $channel,
			];
			return $this->view('NF\Discord:Channel\Delete', 'nf_discord_channel_delete', $viewParams);
		}
	}

	public function actionAlert()
	{
		$api = Api::factory();

		if ($this->isPost())
		{
			$params = [
				'message' => $this->filter('message', 'str'),
				'channels' => $this->filter('channels', 'array-str'),
			];

			if (strlen($params['message']) == 0)
			{
				return $this->error(\XF::phrase('nfd_message_must_not_be_empty'));
			}

			if (strlen($params['message']) > 2000)
			{
				return $this->error(\XF::phrase('nfd_message_too_long'));
			}

			$params['message'] = $this->app()->stringFormatter()->replacePhrasePlaceholders($params['message']);

			if (count($params['channels']) > 0)
			{
				$success = [];
				$failed = [];

				foreach ($params['channels'] as $channel)
				{
					$result = $api->alertChannel($channel, $params);

					if (is_array($result) && array_key_exists('channel_id', $result))
					{
						$success[] = $channel;
						continue;
					}
					$failed[] = $channel;
				}

				return $this->redirect($this->buildLink('discord/channels/alert', [], [
					'sent' => true,
					'success' => count($success),
					'failed' => count($failed),
				]));
			}
		}
		else
		{
			$viewParams = [
				'channels' => $api->getChannelsForOptions(Api::CHANNEL_TYPE_TEXT),
				'success' => $this->filter('success', 'int'),
				'failed' => $this->filter('failed', 'int'),
				'sent' => $this->filter('sent', 'int'),
			];
			return $this->view(
				'NF\Discord:Channel\Alert',
				'nf_discord_channel_alert',
				$viewParams
			);
		}
	}

	protected function assertChannelExists($id, $phraseKey = null)
	{
		$api = Api::factory();

		$channel = $api->getChannel($id);
		if (!$channel)
		{
			if (!$phraseKey)
			{
				$phraseKey = 'requested_page_not_found';
			}

			throw $this->exception(
				$this->notFound(\XF::phrase($phraseKey))
			);
		}

		return $channel;
	}
}