<?php

namespace NF\Discord\ConnectedAccount\Provider;

use NF\Discord\Api;
use OAuth\Common\Http\Uri\Uri;
use XF\ConnectedAccount\Http\HttpResponseException;
use XF\ConnectedAccount\Provider\AbstractProvider;
use XF\ConnectedAccount\Storage\StorageState;
use XF\Entity\ConnectedAccountProvider;
use XF\Http\Request;
use XF\Mvc\Controller;
use NF\Discord\ConnectedAccount\Service\Discord as DiscordService;

class Discord extends AbstractProvider
{
	public function getOAuthServiceName()
	{
		return 'NF\Discord:Service\Discord';
	}

	public function getProviderDataClass()
	{
		return 'NF\Discord:ProviderData\Discord';
	}

	public function getDefaultOptions()
	{
		return [
			'guild_id' => '',
			'client_id' => '',
			'client_secret' => '',
			'token' => '',
		];
	}

	public function isUsable(ConnectedAccountProvider $provider)
	{
		$addOns = \XF::app()->container('addon.cache');
		if (empty($addOns['NF/Discord']))
		{
			return false;
		}

		/** @var \NF\Discord\XF\Entity\User $visitor */
		$visitor = \XF::visitor();
		if (method_exists($visitor, 'canLinkDiscordAccount')
			&& !$visitor->canLinkDiscordAccount())
		{
			return false;
		}

		return parent::isUsable($provider);
	}

	public function isValidForRegistration()
	{
		$addOns = \XF::app()->container('addon.cache');
		if (empty($addOns['NF/Discord']))
		{
			return false;
		}

		if (empty(\XF::options()->nfDiscordAllowDiscordLogin))
		{
			return false;
		}

		/** @var \NF\Discord\XF\Entity\User $visitor */
		$visitor = \XF::visitor();

		return $visitor->canLinkDiscordAccount();
	}

	public function getOAuthConfig(ConnectedAccountProvider $provider, $redirectUri = null)
	{
		$scopes = [
			DiscordService::SCOPE_IDENTIFY,
			DiscordService::SCOPE_EMAIL,
		];

		if (\XF::options()->nfDiscordAssocJoinServer)
		{
			$scopes = array_merge($scopes, [
				DiscordService::SCOPE_GUILDS,
				DiscordService::SCOPE_JOIN_GUILDS,
			]);
		}

		return [
			'key' => $provider->options['client_id'],
			'secret' => $provider->options['client_secret'],
			'grant_type' => 'authorization_code',
			'scopes' => $scopes,
			'redirect' => $redirectUri ?: $this->getRedirectUri($provider),
		];
	}
}