<?php

namespace NF\Discord\Job;

use NF\Discord\Helper;
use XF\Job\AbstractJob;
use XF\Job\JobResult;

class GroupSync extends AbstractJob
{
	protected $defaultData = [
		'position' => 0,
		'batch' => 20,
	];

	public function run($maxRunTime)
	{
		$options = \XF::options();

		$this->data['batch'] = max(1, $this->data['batch']);
		if (!$options->nfDiscordEnableSync)
		{
			return $this->complete();
		}

		$helper = Helper::factory();

		$rawUserIds = $helper->getUserIdsInUserGroup($this->data['user_group_id'], $this->data['batch'], $this->data['position']);
		$userIds = [];
		if (count($rawUserIds) > 0)
		{
			foreach ($rawUserIds as $key => $id)
			{
				$userIds[] = $key;
			}
		}
		if (sizeof($userIds) == 0 || $userIds == null)
		{
			return $this->complete();
		}

		$helper->setUsersServerGroupsByIds($userIds);

		$this->data['position'] = end($userIds);

		return $this->resume();
	}

	public function getStatusMessage()
	{
		$actionPhrase = \XF::phrase('rebuilding');
		$typePhrase = \XF::phrase('nfd_syncing_discord_server_groups');

		return sprintf('%s... %s (%s)', $actionPhrase, $typePhrase, \XF::language()->numberFormat($this->data['position']));
	}

	public function canCancel()
	{
		return true;
	}

	public function canTriggerByChoice()
	{
		return false;
	}
}
