<?php

namespace NF\Discord\Job;

use NF\Discord\Api;
use XF\Job\AbstractJob;

class NotifyOldOpenReports extends AbstractJob
{
	protected $defaultData = [
		'queueId' => null,
	];

	public function run($maxRunTime)
	{
		$addOns = \XF::app()->container('addon.cache');
		if (empty($this->data['queueId']) ||
			empty($addOns['NF/Discord']) || empty($addOns['SV/ReportCentreEssentials']))
		{
			return $this->complete();
		}

		$api = Api::factory(false);
		if (!$api)
		{
			return $this->complete();
		}

		/** @var \NF\Discord\SV\ReportCentreEssentials\Entity\ReportQueue $queue */
		$queue = \XF::finder('SV\ReportCentreEssentials:ReportQueue')
			->where('queue_id', '=', $this->data['queueId'])
			->where('nf_discord_channel_id', '<>', '')
			->where('nf_discord_old_report_first_threshold', '>', 0)
			->fetchOne();
		if (!$queue)
		{
			return $this->complete();
		}

		$ageCheck = \XF::$time - $queue->nf_discord_old_report_first_threshold * 60 * 60;
		// check if an alert has been sent recently
		if ($queue->nf_discord_old_report_repeating)
		{
			$time = \XF::$time - $queue->nf_discord_old_report_repeat_threshold * 60;
		}
		else
		{
			$time = $ageCheck;
		}
		if ($time < $queue->nf_discord_old_report_timestamp)
		{
			return $this->complete();
		}

		$oldReportCount = \XF::finder('XF:Report')
			->where('queue_id', '=', $queue->queue_id)
			->where('report_state', '=', 'open')
			->where('last_modified_date', '<', $ageCheck)
			->total();

		if ($oldReportCount <= 0)
		{
			// reset
			$queue->nf_discord_old_report_repeating = 0;
			$queue->nf_discord_old_report_timestamp = \XF::$time;

			return $this->complete();
		}
		$stats = $queue->stats_;
		if (!isset($stats['open']))
		{
			$db = \XF::db();
			$db->beginTransaction();

			/** @var \SV\ReportCentreEssentials\Repository\ReportQueue $reportQueueRepo */
			$reportQueueRepo = \XF::repository('SV\ReportCentreEssentials:ReportQueue');
			$stats = $reportQueueRepo->getStats($queue);
			$queue->stats = $stats;
			$queue->save(true, false);

			$db->commit();
		}

		// do the thing
		$queue->nf_discord_old_report_repeating = 1;
		$queue->nf_discord_old_report_timestamp = \XF::$time;
		$queue->save();

		$phrase = \XF::phrase('nfDiscord_notice.report_old_open_reports', [
			'queueName' => $queue->queue_name,
			'reportCount' => $oldReportCount,
			'time' => $queue->nf_discord_old_report_first_threshold,
			'openCount' => $stats['open'],
			'assignedCount' => $stats['totalAssigned'],
		]);

		$api->createMessage($queue->nf_discord_channel_id, $phrase->render(), [
			'title' => $queue->queue_name,
			'url' => \XF::app()->router('public')->buildLink('full:reports/queue', $queue),
			'timestamp' => date('c', \XF::$time),
		]);

		return $this->complete();
	}

	public function getStatusMessage()
	{
		return '';
	}

	public function canCancel()
	{
		return false;
	}

	public function canTriggerByChoice()
	{
		return false;
	}
}
