<?php

namespace NF\Discord\Job;

use NF\Discord\Api;
use XF\Job\AbstractJob;

class NotifyTooManyOpenReports extends AbstractJob
{
	protected $defaultData = [
		'queueId' => null,
	];

	public function run($maxRunTime)
	{
		$addOns = \XF::app()->container('addon.cache');
		if (empty($this->data['queueId']) ||
			empty($addOns['NF/Discord']) || empty($addOns['SV/ReportCentreEssentials']))
		{
			return $this->complete();
		}

		$api = Api::factory(false);
		if (!$api)
		{
			return $this->complete();
		}

		/** @var \NF\Discord\SV\ReportCentreEssentials\Entity\ReportQueue $queue */
		$queue = \XF::finder('SV\ReportCentreEssentials:ReportQueue')
			->where('queue_id', '=', $this->data['queueId'])
			->where('nf_discord_channel_id', '<>', '')
			->where('nf_discord_open_threshold', '>', 0)
			->where('nf_discord_open_count', '>', 0)
			->fetchOne();
		if (!$queue)
		{
			return $this->complete();
		}

		// check if an alert has been sent recently
		$time = \XF::$time - $queue->nf_discord_open_threshold * 60;
		if ($time < $queue->nf_discord_open_timestamp)
		{
			return $this->complete();
		}

		$stats = $queue->stats_;
		if (!isset($stats['open']))
		{
			$db = \XF::db();
			$db->beginTransaction();

			/** @var \SV\ReportCentreEssentials\Repository\ReportQueue $reportQueueRepo */
			$reportQueueRepo = \XF::repository('SV\ReportCentreEssentials:ReportQueue');
			$stats = $reportQueueRepo->getStats($queue);
			$queue->stats = $stats;
			$queue->save(true, false);

			$db->commit();
		}
		if ($stats['open'] < $queue->nf_discord_open_count)
		{
			$queue->nf_discord_open_timestamp = \XF::$time;
			$queue->save();
			return $this->complete();
		}

		// do the thing
		$queue->nf_discord_open_timestamp = \XF::$time;
		$queue->save();

		$phrase = \XF::phrase('nfDiscord_notice.report_too_many_open', [
			'queueName' => $queue->queue_name,
			'openCount' => $stats['open'],
			'assignedCount' => $stats['totalAssigned'],
			'openThreshold' => $queue->nf_discord_open_count,
		]);

		$api->createMessage($queue->nf_discord_channel_id, $phrase->render(), [
			'title' => $queue->queue_name,
			'url' => \XF::app()->router('public')->buildLink('full:reports/queue', $queue),
			'timestamp' => date('c', \XF::$time),
		]);

		return $this->complete();
	}

	public function getStatusMessage()
	{
		return '';
	}

	public function canCancel()
	{
		return false;
	}

	public function canTriggerByChoice()
	{
		return false;
	}
}
