<?php

namespace NF\Discord\XF\Entity;

use NF\Discord\Api;

/**
 * Extends \XF\Entity\Post
 */
class Post extends XFCP_Post
{
	/**
	 * @param $noticeType
	 *
	 * @throws \XF\PrintableException
	 */
	public function nfNotifyDiscord($noticeType)
	{
		/** @var Forum $forum */
		$forum = $this->Thread->Forum;
		if (!$forum || empty($forum->nf_discord_channel_id) || !$forum->nf_discord_include_replies)
		{
			return;
		}
		$discordChannelId = $forum->nf_discord_channel_id;

		$app = $this->app();
		$router = \XF::app()->router('public');
		$url = $router->buildLink('full:posts', $this);
		$phrase = \XF::phrase('nfDiscord_notice.' . $noticeType, [
			'name' => $this->username,
			'title' => $this->Thread->title,
			'nodeName' => $forum->title,
			'url' => $url,
		]);

		$snippet = $app->stringFormatter()->stripBbCode($this->message, [
			'stripQuote' => false,
		]);
		$snippet = $app->stringFormatter()->wholeWordTrim($snippet, 500);

		$api = Api::factory(false);
		if ($api)
		{
			$api->createMessage($discordChannelId, $phrase->render('raw'), [
				'author' => [
					'name' => $this->username,
					'url' => $router->buildLink('full:members', $this->User),
					'icon_url' => $this->User->getAvatarUrl('s', null, true)
				],
				'footer' => [
					'text' => $forum->title,
				],
				'title' => $this->Thread->title,
				'url' => $url,
				'description' => $snippet,
				'timestamp' => date('c', $this->post_date),
			]);
		}
	}
}