<?php

namespace NF\Discord\XF\Entity;

use NF\Discord\Api;
use XF\Mvc\Entity\Structure;

/**
 * Extends \XF\Entity\Thread
 */
class Thread extends XFCP_Thread
{
	public function canPromoteToDiscord(/** @noinspection PhpUnusedParameterInspection */ &$error = null)
	{
		$visitor = \XF::visitor();
		return $visitor->user_id && $visitor->hasNodePermission($this->node_id, 'promoteToDiscord');
	}

	/**
	 * @param $noticeType
	 *
	 * @throws \XF\PrintableException
	 */
	public function nfNotifyDiscord($noticeType)
	{
		/** @var Forum $forum */
		$forum = $this->Forum;
		if (!$forum || empty($forum->nf_discord_channel_id))
		{
			return;
		}
		$discordChannelId = $forum->nf_discord_channel_id;

		$app = $this->app();
		$router = \XF::app()->router('public');
		$url = $router->buildLink('full:threads', $this);
		$phrase = \XF::phrase('nfDiscord_notice.' . $noticeType, [
			'name' => $this->username,
			'title' => $this->title,
			'nodeName' => $forum->title,
			'url' => $url,
		]);

		$snippet = $app->stringFormatter()->stripBbCode($this->FirstPost->message, [
			'stripQuote' => false,
		]);
		$snippet = $app->stringFormatter()->wholeWordTrim($snippet, 500);

		$api = Api::factory(false);
		if ($api)
		{
			$api->createMessage($discordChannelId, $phrase->render('raw'), [
				'author' => [
					'name' => $this->username,
					'url' => $router->buildLink('full:members', $this->User),
					'icon_url' => $this->User->getAvatarUrl('s', null, true)
				],
				'footer' => [
					'text' => $forum->title,
				],
				'title' => $this->title,
				'url' => $url,
				'description' => $snippet,
				'timestamp' => date('c', $this->post_date),
			]);
		}
	}

	public static function getStructure(Structure $structure)
	{
		$structure = parent::getStructure($structure);

		$structure->options['nfDiscord'] = true;

		return $structure;
	}
}