<?php

namespace NF\Discord\XF\Pub\Controller;

use NF\Discord\Api;
use XF\Mvc\ParameterBag;

/**
 * Extends \XF\Pub\Controller\Thread
 */
class Thread extends XFCP_Thread
{
	public function actionPromoteToDiscord(ParameterBag $params)
	{
		/** @var \NF\Discord\XF\Entity\Thread $thread */
		$thread = $this->assertViewableThread($params->thread_id);
		if (!$thread->canPromoteToDiscord($error))
		{
			return $this->noPermission($error);
		}
		$forum = $thread->Forum;

		$api = Api::factory(false);
		if (!$api)
		{
			return $this->noPermission();
		}

		if ($this->isPost())
		{
			$post = $thread->FirstPost;

			$snippet = $this->app->stringFormatter()->stripBbCode($post->message, [
				'stripQuote' => false,
			]);
			$snippet = $this->app->stringFormatter()->wholeWordTrim($snippet, 500);

			$channels = $this->filter('channels', 'array-uint');
			foreach ($channels AS $channel)
			{
				$api->createMessage($channel, $this->filter('message', 'str'), [
					'author' => [
						'name' => $thread->username,
						'url' => \XF::app()->router('public')->buildLink('full:members', $thread->User),
					],
					'footer' => [
						'text' => $forum->title,
					],
					'title' => $thread->title,
					'url' => \XF::app()->router('public')->buildLink('full:threads', $thread),
					'description' => $snippet,
					'timestamp' => date('c', $thread->post_date),
				]);
			}

			return $this->redirect($this->buildLink('threads', $thread));
		}
		else
		{
			$viewParams = [
				'thread' => $thread,
				'forum' => $forum,
				'channels' => $api->getChannels(Api::CHANNEL_TYPE_TEXT),
			];
			return $this->view(
				'NF\Discord:Thread\Promote',
				'nf_discord_thread_promote',
				$viewParams
			);
		}
	}
}