<?php

namespace NF\Discord\XF\Service\Report;

use NF\Discord\Api;
use NF\Discord\XF\Entity\ReportComment;
use XF\Mvc\Entity\Entity;

/**
 * Extends \XF\Service\Report\Creator
 */
class Creator extends XFCP_Creator
{
	/** @var bool */
	protected $existingReport = false;

	/** @var bool */
	protected $wasClosed = false;

	public function createReport($contentType, Entity $content)
	{
		parent::createReport($contentType, $content);

		$this->existingReport = $this->report ? $this->report->exists() : false;
		if ($this->existingReport)
		{
			$this->wasClosed = $this->report->isClosed();
		}
	}

	public function sendNotifications()
	{
		parent::sendNotifications();

		$report = $this->report;
		/** @var ReportComment $comment */
		$comment = $this->comment;

		if (!$report || !$report->exists() || !$report->isValidRelation('ReportQueue'))
		{
			return;
		}
		/** @var \SV\ReportCentreEssentials\XF\Entity\Report $report */
		/** @var \NF\Discord\SV\ReportCentreEssentials\Entity\ReportQueue $reportQueue */
		$reportQueue = $report->ReportQueue;

		if ($reportQueue && !empty($reportQueue->nf_discord_channel_id))
		{
			if ($this->existingReport && $this->wasClosed)
			{
				if (!$reportQueue->nf_discord_reopened_reports)
				{
					return;
				}
			}
			else if (!$this->existingReport)
			{
				if (!$reportQueue->nf_discord_new_reports)
				{
					return;
				}
			}
			else
			{
				// existing report that is open/assigned
				return;
			}

			$comment->nfNotifyDiscord($this->wasClosed ? 'report_new' : 'report_reopened');
		}
	}
}